@@ -1,7 +1,7 @@
 """
 Type annotations for sesv2 service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sesv2/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sesv2/type_defs/)
 
 Usage::
 
@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Dict, List, Sequence, Union
+from typing import IO, Any, Dict, List, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -1919,7 +1919,7 @@ PutSuppressedDestinationRequestRequestTypeDef = TypedDict(
 RawMessageTypeDef = TypedDict(
     "RawMessageTypeDef",
     {
-        "Data": Union[bytes, IO[bytes], StreamingBody],
+        "Data": Union[str, bytes, IO[Any], StreamingBody],
     },
 )
 
